Index: trunk/ippScripts/scripts/camera_exp.pl
===================================================================
--- trunk/ippScripts/scripts/camera_exp.pl	(revision 12021)
+++ trunk/ippScripts/scripts/camera_exp.pl	(revision 12079)
@@ -125,5 +125,5 @@
     $workdir = $ipprc->convert_filename_absolute( $workdir );
 } else {
-    my $example = ${$files}[0]->{b1_uri}; # Example original root name
+    my $example = ${$files}[0]->{path_base}; # Example original root name
     my ($vol, $dir, $file) = File::Spec->splitpath( $ipprc->convert_filename_absolute( $example ) );
     $workdir = $dir;
@@ -151,8 +151,7 @@
 my $chipObjects; 
 foreach my $file (@$files) {
     # use the b1_uri as OUTPUT root and convert the filenames
     # with ipprc->filename:
     my $class_id = $file->{class_id};
-    my $origRoot = $ipprc->convert_filename_absolute( $file->{b1_uri} ); # Original root name
+    my $origRoot = $ipprc->convert_filename_absolute( $file->{path_base} ); # Original root name
 
     # if there is only one chip, we use this name for the input to addstar
@@ -230,11 +229,9 @@
 # XXX keep the same outroot as the input
 # Add the result into the database
-$outputRoot = $ipprc->convert_filename_relative($outputRoot);
-$jpeg1  = $ipprc->convert_filename_relative($jpeg1);
-$jpeg2  = $ipprc->convert_filename_relative($jpeg2);
+$outputRoot = $ipprc->convert_filename_relative( $outputRoot );
 
 unless ($no_update) {
     my $command = "$camtool -addprocessedexp -exp_tag $exp_tag -uri UNKNOWN " .
-	"-recip " . RECIPE1() . "," . RECIPE2() . " -b1_uri $outputRoot " .
+	"-recip " . RECIPE1() . "," . RECIPE2() . " -path_base $outputRoot " .
 	"-bg $bg -bg_stdev $bg_stdev -bg_mean_stdev $bg_mean_stdev " .
 	"-sigma_ra 0.0 -sigma_dec 0.0 -nastro 0 -zp_mean 0.0 -zp_stdev 0.0"; # Command to run
@@ -151,8 +151,7 @@
 my $chipObjects; 
 foreach my $file (@$files) {
-    # use the b1_uri as OUTPUT root and convert the filenames
-    # with ipprc->filename:
+    # use the path_base as OUTPUT root and convert the filenames with ipprc->filename:
     my $class_id = $file->{class_id};
